pm4py.evaluation.soundness.woflan package
=========================================

Subpackages
-----------

.. toctree::
   :maxdepth: 4

   pm4py.evaluation.soundness.woflan.graphs
   pm4py.evaluation.soundness.woflan.not_well_handled_pairs
   pm4py.evaluation.soundness.woflan.place_invariants

Submodules
----------

pm4py.evaluation.soundness.woflan.algorithm module
--------------------------------------------------

.. automodule:: pm4py.evaluation.soundness.woflan.algorithm
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: pm4py.evaluation.soundness.woflan
   :members:
   :undoc-members:
   :show-inheritance:
